==> 1.3.1.zip: books-without-borders/src/main/java/net/knarcraft/bookswithoutborders/config/BooksWithoutBordersConfig.java <==
package net.knarcraft.bookswithoutborders.config;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.utility.EconomyHelper;
import org.bukkit.ChatColor;
import org.bukkit.Material;
import org.bukkit.command.ConsoleCommandSender;
import org.bukkit.configuration.Configuration;

import java.util.ArrayList;
import java.util.List;

import static net.knarcraft.bookswithoutborders.BooksWithoutBorders.sendErrorMessage;
import static net.knarcraft.bookswithoutborders.BooksWithoutBorders.sendSuccessMessage;
import static net.knarcraft.bookswithoutborders.utility.InputCleaningHelper.cleanString;

/**
 * A config class that keeps track of all config values
 */
public class BooksWithoutBordersConfig {

    private static final ChatColor errorColor = ChatColor.RED;
    private static final ChatColor successColor = ChatColor.GREEN;
    private static final ChatColor commandColor = ChatColor.YELLOW;
    private static final String SLASH = System.getProperty("file.separator");
    private static boolean isInitialized;
    public static String bookFolder;

    private static int bookDuplicateLimit;
    private static String titleAuthorSeparator;
    private static String loreSeparator;
    private static List<String> firstBooks = new ArrayList<>();
    private static String welcomeMessage;
    private static Material bookPriceType = null;
    private static double bookPriceQuantity;
    private static boolean authorOnlyCopy;
    private static boolean authorOnlyUnsign;
    private static boolean authorOnlySave;
    private static boolean useYml;
    private static boolean adminDecrypt;
    private static boolean formatBooks;
    private static boolean changeGenerationOnCopy;

    /**
     * Initializes the books without borders settings class
     *
     * @param booksWithoutBorders <p>The books without borders object used for getting required data</p>
     */
    public static void initialize(BooksWithoutBorders booksWithoutBorders) {
        if (isInitialized) {
            throw new IllegalArgumentException("Settings class initialized twice. This should not happen!");
        }
        isInitialized = true;
        bookFolder = booksWithoutBorders.getDataFolder().getAbsolutePath() + getSlash() + "Books" + getSlash();
        loadConfig();
    }

    /**
     * Gets the folder used for storing books
     *
     * @return <p>The folder used for storing books</p>
     */
    public static String getBookFolder() {
        return bookFolder;
    }

    /**
     * Gets the color to use for error messages
     *
     * @return <p>The color to use for error messages</p>
     */
    public static ChatColor getErrorColor() {
        return errorColor;
    }

    /**
     * Gets the color to use for success messages
     *
     * @return <p>The color to use for success messages</p>
     */
    public static ChatColor getSuccessColor() {
        return successColor;
    }

    /**
     * Gets the color used to color commands
     *
     * @return <p>The color used to color commands</p>
     */
    public static ChatColor getCommandColor() {
        return commandColor;
    }

    /**
     * Gets the correct slash to use for the used OS
     *
     * @return <p>The slash to use for file separators</p>
     */
    public static String getSlash() {
        return SLASH;
    }

    /**
     * Gets whether only the author of a book should be able to copy it
     *
     * @return <p>Whether only the book author can copy it</p>
     */
    public static boolean getAuthorOnlyCopy() {
        return authorOnlyCopy;
    }

    /**
     * Gets whether only the author of a book should be able to unsign it
     *
     * @return <p>Whether only the book author can unsign it</p>
     */
    public static boolean getAuthorOnlyUnsign() {
        return authorOnlyUnsign;
    }

    /**
     * Gets whether a player can only save their own books with /savebook
     *
     * @return <p>Whether a player can only save their own books</p>
     */
    public static boolean getAuthorOnlySave() {
        return authorOnlySave;
    }

    /**
     * Gets whether to use YML, not TXT, for saving books
     *
     * @return <p>Whether to use YML for saving books</p>
     */
    public static boolean getUseYml() {
        return useYml;
    }

    /**
     * Gets whether admins should be able to decrypt books without a password, and decrypt all group encrypted books
     *
     * @return <p>Whether admins can bypass the encryption password</p>
     */
    public static boolean getAdminDecrypt() {
        return adminDecrypt;
    }

    /**
     * Sets the quantity of items/currency necessary for copying books
     *
     * @param newQuantity <p>The new quantity necessary for payment</p>
     */
    public static void setBookPriceQuantity(double newQuantity) {
        bookPriceQuantity = newQuantity;
    }

    /**
     * Gets the quantity of items/currency necessary for copying books
     *
     * @return <p>The quantity necessary for payment</p>
     */
    public static double getBookPriceQuantity() {
        return bookPriceQuantity;
    }

    /**
     * Sets the item type used for book pricing
     *
     * <p>This item is the one a player has to pay for copying books. AIR is used to denote economy. null is used if
     * payment is disabled. Otherwise, any item can be used.</p>
     *
     * @param newType <p>The new item type to use for book pricing</p>
     */
    public static void setBookPriceType(Material newType) {
        bookPriceType = newType;
    }

    /**
     * Gets the item type used for book pricing
     *
     * <p>This item is the one a player has to pay for copying books. AIR is used to denote economy. null is used if
     * payment is disabled. Otherwise, any item can be used.</p>
     *
     * @return <p>The item type used for book pricing</p>
     */
    public static Material getBookPriceType() {
        return bookPriceType;
    }

    /**
     * Gets the welcome message to show to new players
     *
     * @return <p>The welcome message to show new players</p>
     */
    public static String getWelcomeMessage() {
        return welcomeMessage;
    }

    /**
     * Gets the limit of duplicates for each book
     *
     * @return <p>The book duplicate limit</p>
     */
    public static int getBookDuplicateLimit() {
        return bookDuplicateLimit;
    }

    /**
     * Gets whether books should change their generation during copy
     *
     * @return <p>True if books should change their generation</p>
     */
    public static boolean changeGenerationOnCopy() {
        return changeGenerationOnCopy;
    }

    /**
     * Gets the separator used to split book title from book author
     *
     * @return <p>The separator between title and author</p>
     */
    public static String getTitleAuthorSeparator() {
        return titleAuthorSeparator;
    }

    /**
     * Gets the separator used to denote a newline in a lore string
     *
     * @return <p>The separator used to denote lore newline</p>
     */
    public static String getLoreSeparator() {
        return loreSeparator;
    }

    /**
     * Gets whether all books should be formatted when they are signed
     *
     * @return <p>Whether all books should be formatted</p>
     */
    public static boolean formatBooks() {
        return formatBooks;
    }

    /**
     * Gets a copy of the list of books to give new players
     *
     * @return <p>The books to give new players</p>
     */
    public static List<String> getFirstBooks() {
        return new ArrayList<>(firstBooks);
    }

    /**
     * Checks whether books have a price for printing them
     *
     * @return <p>True if players need to pay for printing books</p>
     */
    public static boolean booksHavePrice() {
        return (bookPriceType != null && bookPriceQuantity > 0);
    }

    /**
     * Saves the config
     */
    public static void saveConfigValues() {
        ConsoleCommandSender consoleSender = BooksWithoutBorders.getInstance().getServer().getConsoleSender();
        Configuration config = BooksWithoutBorders.getInstance().getConfig();
        config.set(ConfigOption.USE_YAML.getConfigNode(), useYml);
        config.set(ConfigOption.MAX_DUPLICATES.getConfigNode(), bookDuplicateLimit);
        config.set(ConfigOption.TITLE_AUTHOR_SEPARATOR.getConfigNode(), titleAuthorSeparator);
        config.set(ConfigOption.LORE_LINE_SEPARATOR.getConfigNode(), loreSeparator);
        config.set(ConfigOption.BOOKS_FOR_NEW_PLAYERS.getConfigNode(), firstBooks);
        config.set(ConfigOption.MESSAGE_FOR_NEW_PLAYERS.getConfigNode(), welcomeMessage);
        config.set(ConfigOption.FORMAT_AFTER_SIGNING.getConfigNode(), formatBooks);

        String itemTypeNode = ConfigOption.PRICE_ITEM_TYPE.getConfigNode();
        if (bookPriceType != null) {
            if (bookPriceType != Material.AIR) {
                config.set(itemTypeNode, bookPriceType.toString());
            } else {
                config.set(itemTypeNode, "Economy");
            }
        } else {
            config.set(itemTypeNode, "Item type name");
        }

        config.set(ConfigOption.PRICE_QUANTITY.getConfigNode(), bookPriceQuantity);
        config.set(ConfigOption.ADMIN_AUTO_DECRYPT.getConfigNode(), adminDecrypt);
        config.set(ConfigOption.AUTHOR_ONLY_COPY.getConfigNode(), authorOnlyCopy);
        config.set(ConfigOption.AUTHOR_ONLY_UNSIGN.getConfigNode(), authorOnlyUnsign);
        config.set(ConfigOption.AUTHOR_ONLY_SAVE.getConfigNode(), authorOnlySave);
        config.set(ConfigOption.CHANGE_GENERATION_ON_COPY.getConfigNode(), changeGenerationOnCopy);

        //Handles old book and quill settings
        if (config.contains("Options.Require_book_and_quill_to_create_book")) {
            sendSuccessMessage(consoleSender, "[BooksWithoutBorders] Found old config setting " +
                    "\"Require_book_and_quill_to_create_book\"");
            sendSuccessMessage(consoleSender, "Updating to \"Price_to_create_book\" settings");

            if (config.getBoolean("Options.Require_book_and_quill_to_create_book")) {
                bookPriceType = Material.WRITABLE_BOOK;
                bookPriceQuantity = 1;
                config.set("Options.Price_to_create_book.Item_type", bookPriceType.toString());
                config.set("Options.Price_to_create_book.Required_quantity", bookPriceQuantity);
            }
            config.set("Options.Require_book_and_quill_to_create_book", null);
        }
        BooksWithoutBorders.getInstance().saveConfig();
    }

    /**
     * Loads the config
     *
     * @return <p>True if the config was loaded successfully</p>
     */
    public static boolean loadConfig() {
        ConsoleCommandSender consoleSender = BooksWithoutBorders.getInstance().getServer().getConsoleSender();
        BooksWithoutBorders.getInstance().reloadConfig();
        Configuration config = BooksWithoutBorders.getInstance().getConfig();
        try {
            useYml = getBoolean(config, ConfigOption.USE_YAML);
            bookDuplicateLimit = getInt(config, ConfigOption.MAX_DUPLICATES);
            titleAuthorSeparator = getString(config, ConfigOption.TITLE_AUTHOR_SEPARATOR);
            loreSeparator = getString(config, ConfigOption.LORE_LINE_SEPARATOR);
            adminDecrypt = getBoolean(config, ConfigOption.ADMIN_AUTO_DECRYPT);
            authorOnlyCopy = getBoolean(config, ConfigOption.AUTHOR_ONLY_COPY);
            authorOnlyUnsign = getBoolean(config, ConfigOption.AUTHOR_ONLY_UNSIGN);
            authorOnlySave = getBoolean(config, ConfigOption.AUTHOR_ONLY_SAVE);
            firstBooks = config.getStringList(ConfigOption.BOOKS_FOR_NEW_PLAYERS.getConfigNode());
            welcomeMessage = getString(config, ConfigOption.MESSAGE_FOR_NEW_PLAYERS);
            formatBooks = getBoolean(config, ConfigOption.FORMAT_AFTER_SIGNING);
            changeGenerationOnCopy = getBoolean(config, ConfigOption.CHANGE_GENERATION_ON_COPY);

            //Convert string into material
            String paymentMaterial = getString(config, ConfigOption.PRICE_ITEM_TYPE);
            if (paymentMaterial.equalsIgnoreCase("Economy")) {
                if (EconomyHelper.setupEconomy()) {
                    bookPriceType = Material.AIR;
                } else {
                    sendErrorMessage(consoleSender,
                            "BooksWithoutBorders failed to hook into Vault! Book price not set!");
                    bookPriceType = null;
                }
            } else if (!paymentMaterial.trim().isEmpty()) {
                Material material = Material.matchMaterial(paymentMaterial);
                if (material != null) {
                    bookPriceType = material;
                }
            }
            bookPriceQuantity = getDouble(config, ConfigOption.PRICE_QUANTITY);

            //Make sure titleAuthorSeparator is a valid value
            titleAuthorSeparator = cleanString(titleAuthorSeparator);
            if (titleAuthorSeparator.length() != 1) {
                sendErrorMessage(consoleSender, "Title-Author_Separator is set to an invalid value!");
                sendErrorMessage(consoleSender, "Reverting to default value of \",\"");
                titleAuthorSeparator = ",";
                config.set("Options.Title-Author_Separator", titleAuthorSeparator);
            }
        } catch (Exception e) {
            sendErrorMessage(consoleSender, "Warning! Config.yml failed to load!");
            sendErrorMessage(consoleSender, "Try Looking for settings that are missing values!");
            return false;
        }

        return true;
    }

    /**
     * Gets the double value of the given config option
     *
     * @param config       <p>The configuration to read from</p>
     * @param configOption <p>The configuration option to get the value for</p>
     * @return <p>The value of the option</p>
     */
    private static double getDouble(Configuration config, ConfigOption configOption) {
        return config.getDouble(configOption.getConfigNode(), (Double) configOption.getDefaultValue());
    }

    /**
     * Gets the integer value of the given config option
     *
     * @param config       <p>The configuration to read from</p>
     * @param configOption <p>The configuration option to get the value for</p>
     * @return <p>The value of the option</p>
     */
    private static int getInt(Configuration config, ConfigOption configOption) {
        return config.getInt(configOption.getConfigNode(), (Integer) configOption.getDefaultValue());
    }

    /**
     * Gets the string value of the given config option
     *
     * @param config       <p>The configuration to read from</p>
     * @param configOption <p>The configuration option to get the value for</p>
     * @return <p>The value of the option</p>
     */
    private static String getString(Configuration config, ConfigOption configOption) {
        return config.getString(configOption.getConfigNode(), (String) configOption.getDefaultValue());
    }

    /**
     * Gets the boolean value of the given config option
     *
     * @param config       <p>The configuration to read from</p>
     * @param configOption <p>The configuration option to get the value for</p>
     * @return <p>The value of the option</p>
     */
    private static boolean getBoolean(Configuration config, ConfigOption configOption) {
        return config.getBoolean(configOption.getConfigNode(), (Boolean) configOption.getDefaultValue());
    }

}

==> 1.3.5.zip: books-without-borders/src/main/java/net/knarcraft/bookswithoutborders/config/BooksWithoutBordersConfig.java <==
package net.knarcraft.bookswithoutborders.config;

import net.knarcraft.bookswithoutborders.BooksWithoutBorders;
import net.knarcraft.bookswithoutborders.utility.EconomyHelper;
import net.md_5.bungee.api.ChatColor;
import org.bukkit.Material;
import org.bukkit.command.ConsoleCommandSender;
import org.bukkit.configuration.Configuration;

import java.nio.file.FileSystems;
import java.util.ArrayList;
import java.util.List;

import static net.knarcraft.bookswithoutborders.BooksWithoutBorders.sendErrorMessage;
import static net.knarcraft.bookswithoutborders.BooksWithoutBorders.sendSuccessMessage;
import static net.knarcraft.bookswithoutborders.utility.InputCleaningHelper.cleanString;

/**
 * A config class that keeps track of all config values
 */
public class BooksWithoutBordersConfig {

    private static final ChatColor errorColor = ChatColor.RED;
    private static final ChatColor successColor = ChatColor.GREEN;
    private static final ChatColor commandColor = ChatColor.YELLOW;
    private static final String SLASH = FileSystems.getDefault().getSeparator();
    private static boolean isInitialized;
    public static String bookFolder;

    private static int bookDuplicateLimit;
    private static String titleAuthorSeparator;
    private static String loreSeparator;
    private static List<String> firstBooks = new ArrayList<>();
    private static String welcomeMessage;
    private static Material bookPriceType = null;
    private static double bookPriceQuantity;
    private static boolean authorOnlyCopy;
    private static boolean authorOnlyUnsign;
    private static boolean authorOnlySave;
    private static boolean useYml;
    private static boolean adminDecrypt;
    private static boolean formatBooks;
    private static boolean changeGenerationOnCopy;
    private static boolean enableBookshelfPeeking;

    /**
     * Initializes the books without borders settings class
     *
     * @param booksWithoutBorders <p>The books without borders object used for getting required data</p>
     */
    public static void initialize(BooksWithoutBorders booksWithoutBorders) {
        if (isInitialized) {
            throw new IllegalArgumentException("Settings class initialized twice. This should not happen!");
        }
        isInitialized = true;
        bookFolder = booksWithoutBorders.getDataFolder().getAbsolutePath() + getSlash() + "Books" + getSlash();
        loadConfig();
    }

    /**
     * Gets the folder used for storing books
     *
     * @return <p>The folder used for storing books</p>
     */
    public static String getBookFolder() {
        return bookFolder;
    }

    /**
     * Gets the color to use for error messages
     *
     * @return <p>The color to use for error messages</p>
     */
    public static ChatColor getErrorColor() {
        return errorColor;
    }

    /**
     * Gets the color to use for success messages
     *
     * @return <p>The color to use for success messages</p>
     */
    public static ChatColor getSuccessColor() {
        return successColor;
    }

    /**
     * Gets the color used to color commands
     *
     * @return <p>The color used to color commands</p>
     */
    public static ChatColor getCommandColor() {
        return commandColor;
    }

    /**
     * Gets the correct slash to use for the used OS
     *
     * @return <p>The slash to use for file separators</p>
     */
    public static String getSlash() {
        return SLASH;
    }

    /**
     * Gets whether only the author of a book should be able to copy it
     *
     * @return <p>Whether only the book author can copy it</p>
     */
    public static boolean getAuthorOnlyCopy() {
        return authorOnlyCopy;
    }

    /**
     * Gets whether only the author of a book should be able to unsign it
     *
     * @return <p>Whether only the book author can unsign it</p>
     */
    public static boolean getAuthorOnlyUnsign() {
        return authorOnlyUnsign;
    }

    /**
     * Gets whether a player can only save their own books with /savebook
     *
     * @return <p>Whether a player can only save their own books</p>
     */
    public static boolean getAuthorOnlySave() {
        return authorOnlySave;
    }

    /**
     * Gets whether players can left-click a bookshelf to peek at the contained books
     *
     * @return <p>True if players can peek at the contained books</p>
     */
    public static boolean getEnableBookshelfPeeking() {
        return enableBookshelfPeeking;
    }

    /**
     * Gets whether to use YML, not TXT, for saving books
     *
     * @return <p>Whether to use YML for saving books</p>
     */
    public static boolean getUseYml() {
        return useYml;
    }

    /**
     * Gets whether admins should be able to decrypt books without a password, and decrypt all group encrypted books
     *
     * @return <p>Whether admins can bypass the encryption password</p>
     */
    public static boolean getAdminDecrypt() {
        return adminDecrypt;
    }

    /**
     * Sets the quantity of items/currency necessary for copying books
     *
     * @param newQuantity <p>The new quantity necessary for payment</p>
     */
    public static void setBookPriceQuantity(double newQuantity) {
        bookPriceQuantity = newQuantity;
    }

    /**
     * Gets the quantity of items/currency necessary for copying books
     *
     * @return <p>The quantity necessary for payment</p>
     */
    public static double getBookPriceQuantity() {
        return bookPriceQuantity;
    }

    /**
     * Sets the item type used for book pricing
     *
     * <p>This item is the one a player has to pay for copying books. AIR is used to denote economy. null is used if
     * payment is disabled. Otherwise, any item can be used.</p>
     *
     * @param newType <p>The new item type to use for book pricing</p>
     */
    public static void setBookPriceType(Material newType) {
        bookPriceType = newType;
    }

    /**
     * Gets the item type used for book pricing
     *
     * <p>This item is the one a player has to pay for copying books. AIR is used to denote economy. null is used if
     * payment is disabled. Otherwise, any item can be used.</p>
     *
     * @return <p>The item type used for book pricing</p>
     */
    public static Material getBookPriceType() {
        return bookPriceType;
    }

    /**
     * Gets the welcome message to show to new players
     *
     * @return <p>The welcome message to show new players</p>
     */
    public static String getWelcomeMessage() {
        return welcomeMessage;
    }

    /**
     * Gets the limit of duplicates for each book
     *
     * @return <p>The book duplicate limit</p>
     */
    public static int getBookDuplicateLimit() {
        return bookDuplicateLimit;
    }

    /**
     * Gets whether books should change their generation during copy
     *
     * @return <p>True if books should change their generation</p>
     */
    public static boolean changeGenerationOnCopy() {
        return changeGenerationOnCopy;
    }

    /**
     * Gets the separator used to split book title from book author
     *
     * @return <p>The separator between title and author</p>
     */
    public static String getTitleAuthorSeparator() {
        return titleAuthorSeparator;
    }

    /**
     * Gets the separator used to denote a newline in a lore string
     *
     * @return <p>The separator used to denote lore newline</p>
     */
    public static String getLoreSeparator() {
        return loreSeparator;
    }

    /**
     * Gets whether all books should be formatted when they are signed
     *
     * @return <p>Whether all books should be formatted</p>
     */
    public static boolean formatBooks() {
        return formatBooks;
    }

    /**
     * Gets a copy of the list of books to give new players
     *
     * @return <p>The books to give new players</p>
     */
    public static List<String> getFirstBooks() {
        return new ArrayList<>(firstBooks);
    }

    /**
     * Checks whether books have a price for printing them
     *
     * @return <p>True if players need to pay for printing books</p>
     */
    public static boolean booksHavePrice() {
        return (bookPriceType != null && bookPriceQuantity > 0);
    }

    /**
     * Saves the config
     */
    public static void saveConfigValues() {
        ConsoleCommandSender consoleSender = BooksWithoutBorders.getInstance().getServer().getConsoleSender();
        Configuration config = BooksWithoutBorders.getInstance().getConfig();
        config.set(ConfigOption.USE_YAML.getConfigNode(), useYml);
        config.set(ConfigOption.MAX_DUPLICATES.getConfigNode(), bookDuplicateLimit);
        config.set(ConfigOption.TITLE_AUTHOR_SEPARATOR.getConfigNode(), titleAuthorSeparator);
        config.set(ConfigOption.LORE_LINE_SEPARATOR.getConfigNode(), loreSeparator);
        config.set(ConfigOption.BOOKS_FOR_NEW_PLAYERS.getConfigNode(), firstBooks);
        config.set(ConfigOption.MESSAGE_FOR_NEW_PLAYERS.getConfigNode(), welcomeMessage);
        config.set(ConfigOption.FORMAT_AFTER_SIGNING.getConfigNode(), formatBooks);
        config.set(ConfigOption.ENABLE_BOOKSHELF_PEEKING.getConfigNode(), enableBookshelfPeeking);

        String itemTypeNode = ConfigOption.PRICE_ITEM_TYPE.getConfigNode();
        if (bookPriceType != null) {
            if (bookPriceType != Material.AIR) {
                config.set(itemTypeNode, bookPriceType.toString());
            } else {
                config.set(itemTypeNode, "Economy");
            }
        } else {
            config.set(itemTypeNode, "Item type name");
        }

        config.set(ConfigOption.PRICE_QUANTITY.getConfigNode(), bookPriceQuantity);
        config.set(ConfigOption.ADMIN_AUTO_DECRYPT.getConfigNode(), adminDecrypt);
        config.set(ConfigOption.AUTHOR_ONLY_COPY.getConfigNode(), authorOnlyCopy);
        config.set(ConfigOption.AUTHOR_ONLY_UNSIGN.getConfigNode(), authorOnlyUnsign);
        config.set(ConfigOption.AUTHOR_ONLY_SAVE.getConfigNode(), authorOnlySave);
        config.set(ConfigOption.CHANGE_GENERATION_ON_COPY.getConfigNode(), changeGenerationOnCopy);

        //Handles old book and quill settings
        if (config.contains("Options.Require_book_and_quill_to_create_book")) {
            sendSuccessMessage(consoleSender, "[BooksWithoutBorders] Found old config setting " +
                    "\"Require_book_and_quill_to_create_book\"");
            sendSuccessMessage(consoleSender, "Updating to \"Price_to_create_book\" settings");

            if (config.getBoolean("Options.Require_book_and_quill_to_create_book")) {
                bookPriceType = Material.WRITABLE_BOOK;
                bookPriceQuantity = 1;
                config.set("Options.Price_to_create_book.Item_type", bookPriceType.toString());
                config.set("Options.Price_to_create_book.Required_quantity", bookPriceQuantity);
            }
            config.set("Options.Require_book_and_quill_to_create_book", null);
        }
        BooksWithoutBorders.getInstance().saveConfig();
    }

    /**
     * Loads the config
     *
     * @return <p>True if the config was loaded successfully</p>
     */
    public static boolean loadConfig() {
        ConsoleCommandSender consoleSender = BooksWithoutBorders.getInstance().getServer().getConsoleSender();
        BooksWithoutBorders.getInstance().reloadConfig();
        Configuration config = BooksWithoutBorders.getInstance().getConfig();
        try {
            useYml = getBoolean(config, ConfigOption.USE_YAML);
            bookDuplicateLimit = config.getInt(ConfigOption.MAX_DUPLICATES.getConfigNode(),
                    (Integer) ConfigOption.MAX_DUPLICATES.getDefaultValue());
            titleAuthorSeparator = getString(config, ConfigOption.TITLE_AUTHOR_SEPARATOR);
            loreSeparator = getString(config, ConfigOption.LORE_LINE_SEPARATOR);
            adminDecrypt = getBoolean(config, ConfigOption.ADMIN_AUTO_DECRYPT);
            authorOnlyCopy = getBoolean(config, ConfigOption.AUTHOR_ONLY_COPY);
            authorOnlyUnsign = getBoolean(config, ConfigOption.AUTHOR_ONLY_UNSIGN);
            authorOnlySave = getBoolean(config, ConfigOption.AUTHOR_ONLY_SAVE);
            firstBooks = config.getStringList(ConfigOption.BOOKS_FOR_NEW_PLAYERS.getConfigNode());
            welcomeMessage = getString(config, ConfigOption.MESSAGE_FOR_NEW_PLAYERS);
            formatBooks = getBoolean(config, ConfigOption.FORMAT_AFTER_SIGNING);
            changeGenerationOnCopy = getBoolean(config, ConfigOption.CHANGE_GENERATION_ON_COPY);
            enableBookshelfPeeking = getBoolean(config, ConfigOption.ENABLE_BOOKSHELF_PEEKING);

            //Convert string into material
            String paymentMaterial = getString(config, ConfigOption.PRICE_ITEM_TYPE);
            if (paymentMaterial.equalsIgnoreCase("Economy")) {
                if (EconomyHelper.setupEconomy()) {
                    bookPriceType = Material.AIR;
                } else {
                    sendErrorMessage(consoleSender,
                            "BooksWithoutBorders failed to hook into Vault! Book price not set!");
                    bookPriceType = null;
                }
            } else if (!paymentMaterial.trim().isEmpty()) {
                Material material = Material.matchMaterial(paymentMaterial);
                if (material != null) {
                    bookPriceType = material;
                }
            }
            bookPriceQuantity = config.getDouble(ConfigOption.PRICE_QUANTITY.getConfigNode(),
                    (Double) ConfigOption.PRICE_QUANTITY.getDefaultValue());

            //Make sure titleAuthorSeparator is a valid value
            titleAuthorSeparator = cleanString(titleAuthorSeparator);
            if (titleAuthorSeparator.length() != 1) {
                sendErrorMessage(consoleSender, "Title-Author_Separator is set to an invalid value!");
                sendErrorMessage(consoleSender, "Reverting to default value of \",\"");
                titleAuthorSeparator = ",";
                config.set("Options.Title-Author_Separator", titleAuthorSeparator);
            }
        } catch (Exception e) {
            sendErrorMessage(consoleSender, "Warning! Config.yml failed to load!");
            sendErrorMessage(consoleSender, "Try Looking for settings that are missing values!");
            return false;
        }

        return true;
    }

    /**
     * Gets the string value of the given config option
     *
     * @param config       <p>The configuration to read from</p>
     * @param configOption <p>The configuration option to get the value for</p>
     * @return <p>The value of the option</p>
     */
    private static String getString(Configuration config, ConfigOption configOption) {
        return config.getString(configOption.getConfigNode(), (String) configOption.getDefaultValue());
    }

    /**
     * Gets the boolean value of the given config option
     *
     * @param config       <p>The configuration to read from</p>
     * @param configOption <p>The configuration option to get the value for</p>
     * @return <p>The value of the option</p>
     */
    private static boolean getBoolean(Configuration config, ConfigOption configOption) {
        return config.getBoolean(configOption.getConfigNode(), (Boolean) configOption.getDefaultValue());
    }

}
